@@ -35,12 +35,27 @@ class StripJsdict(object):
     def __init__(self,form):
         self.__dict__["_StripJsdict__f"] = form
     
-    def __getattr__(self,name):
-        return getattr(self.__f)
-
     def __getattr__(self,name):
         return self.__f[name].strip(WHITE_SPACE)
         
     def __getitem__(self,name):
         return self.__f[name].strip(WHITE_SPACE)
 
+    def __iter__(self):
+        for i in self.__f:
+            yield i
+
+    def __nonzero__(self):
+        return bool(self.__f)
+
+    def __setattr__(self,name,value):
+        self.__f[name] = value
+
+    def __contains__(self,b):
+        return b in self.__f
+
+    def __setitem__(self,name,val):
+        self.__f[name] = val
+        
+    def __delitem__(self,name):
+        del self.__f[name]
