@@ -1,10 +1,10 @@
 def start():
     try:
         from simple_server import run
-        run('0.0.0.0',9889)
+        run(9889)
     except:
         import traceback
-        trackback.print_exc()
+        traceback.print_exc()
 
 from time import sleep
 from mypy.reload_server import auto_reload
@@ -15,4 +15,4 @@ while 1:
     for i in xrange(10,0,-1):
         sleep(0.4)
         print i,
-    print ""
\ No newline at end of file
+    print ""
