@@ -3,11 +3,10 @@
 from types import FunctionType
 from byteplay import Code, opmap
 
-from render import Gobj,render_func,render_doc,get_request
+from render import Render,render_func,render_doc,get_request
 from urlroute import Route
 from decorator import decorator
 
-
 _ROUTE = Route()
 
 def _transmute(opcode, arg):
@@ -54,4 +53,5 @@ def route_render_func(func):
     return _ROUTE(render_func(func))
 
 def route_render_doc(func):
-    return _ROUTE(route_render_doc(func))
\ No newline at end of file
+    return _ROUTE(route_render_doc(func))
+    
